@@ -17,14 +17,34 @@ class ProviderException(Exception):
     u""" Ошибка провайдера данных.
 
     Базовое исключение для всех ошибок провайдера данных.
+
     """
-    pass
+    def __init__(self, source=None, field=None, key=None):
+        self.source = source 
+        self.field = field
+        self.key = key
+        self._message_tpl = '@source={source} @field={field} @key={key}'
+        super(ProviderException, self).__init__(self._build_message())
+
+    def _build_message(self):
+        message = ''
+        if self.source and self.field and self.key:
+            try:
+                source_name = self.source.__name__
+            except AttributeError:
+                source_name = self.source.__class__.__name__
+            message = self._message_tpl.format(
+                source=source_name,
+                field=self.field,
+                key=self.key)
+        return message
 
 
 class ObjectDoesNotExists(ProviderException):
     u""" Запись не существует.
 
     Возникает если не удалось найти запись по фильтру.
+
     """
     pass
 
@@ -33,5 +53,6 @@ class MultipleObjects(ProviderException):
     u""" Множественные данные вместо единичной записи.
 
     Возникает если по фильтру было получено больше одной записи.
+
     """
     pass
