@@ -205,11 +205,17 @@ class DjangoModelProvider(BaseRecordProvider):
         try:
             record = self.get_manager(query_object).get((self.key_field, key))
         except self.data_source.DoesNotExist:
-            raise ObjectDoesNotExists
+            raise ObjectDoesNotExists(
+                source=self.data_source,
+                field=self.key_field,
+                key=key)
         except self.data_source.MultipleObjectsReturned:
-            raise MultipleObjects
-
-        return record
+            raise MultipleObjects(
+                source=self.data_source,
+                field=self.key_field,
+                key=key)
+        else:
+            return record
 
     def _preprocess_record(self, obj, context=None):
         u"""
